/* 
   Standard Model Beta functions at 3 loops. 
   Sources:
   1210.6873, 1212.6829, 1303.4364, Bednyakov, Pikelner, Velizhanin
   Checked in part with
   1205.2892, 1303.2890, Chetyrkin and Zoller,
   and 
   0111190 Ford, Jack, Jones.

   kappa = 1/(16 Pi^2).
   zeta3 = Zeta[3] = 1.2020569031595943;

   Running parameters are:
   g3, g, gp = gauge couplings.
   yt, yb, ytau = Yukawa couplings.
   v  = VEV in normalization where v=246 GeV.
   k = lambda = Higgs^4 coupling in normalization where mh^2 = 2 k v^2;
   m2 = negative Higgs mass^2 parameter.

   BetaX = Q dX/dQ
   gamma = -Q d[ln(v)]/dQ

   Betag3 = kappa betag31 + kappa^2 betag32 + kappa^3 betag33;
   Betag = kappa betag1 + kappa^2 betag2 + kappa^3 betag3;
   Betagp = kappa betagp1 + kappa^2 betagp2 + kappa^3 betagp3;
   Betayt = kappa betayt1 + kappa^2 betayt2 + kappa^3 betayt3;
   Betayb = kappa betayb1 + kappa^2 betayb2 + kappa^3 betayb3;
   Betaytau = kappa betaytau1 + kappa^2 betaytau2 + kappa^3 betaytau3;
   Betak = kappa betak1 + kappa^2 betak2 + kappa^3 betak3;
   Betam2 = m2 (kappa betam21 + kappa^2 betam22 + kappa^3 betam23);
   gamma = kappa gamma1 + kappa^2 gamma2 + kappa^3 gamma3;

*/

#include "smh_internal.h"

/* ---------------------------------------------------------------- */
/* ---------------------------------------------------------------- */
/* Full 3-loop SM beta functions. */

/* So we can leave them in the formulas for now... */
#define yb2   0
#define yb3   0
#define yb4   0
#define yb5   0
#define yb6   0
#define yb7   0
#define yb8   0
#define ytau2 0
#define ytau3 0
#define ytau4 0
#define ytau5 0
#define ytau6 0
#define ytau7 0
#define ytau8 0

int SMH_Betas (int loopOrder)
{ 
  TSIL_REAL betag31, betag32, betag33;
  TSIL_REAL betag1, betag2, betag3;
  TSIL_REAL betagp1, betagp2, betagp3;
  TSIL_REAL betayt1, betayt2, betayt3;
/*   TSIL_REAL betayb1, betayb2, betayb3; */
/*   TSIL_REAL betaytau1, betaytau2, betaytau3; */
  TSIL_REAL betak1, betak2, betak3;
  TSIL_REAL betam21, betam22, betam23;
  TSIL_REAL gamma, gamma1, gamma2, gamma3;

  /* Probably just substitute these eventually... */
  TSIL_REAL kappa = ONELOOPFACTOR;
  TSIL_REAL kappa2 = TWOLOOPFACTOR;
  TSIL_REAL kappa3 = THREELOOPFACTOR;

  SMH_Update ();

  betag31 = -7*g33;

  betag1 = (-19*g3_)/6;

  betagp1 = (41*gp3)/6;

  betayt1 = (-9*g2*yt)/4 - 8*g32*yt - (17*gp2*yt)/12 + (3*yb2*yt)/2 +
    (9*yt3)/2 + yt*ytau2;

/*   betayb1 = (-9*g2*yb)/4 - 8*g32*yb - (5*gp2*yb)/12 + (9*yb3)/2 + */
/*     (3*yb*yt2)/2 + yb*ytau2; */
 
/*   betaytau1 = (-9*g2*ytau)/4 - (15*gp2*ytau)/4 + 3*yb2*ytau + 3*yt2*ytau + */
/*     (5*ytau3)/2; */
 
  betak1 = (9*g4)/8 + (3*g2*gp2)/4 + (3*gp4)/8 - 9*g2*k - 3*gp2*k +
    24*k2 + 12*k*yb2 - 6*yb4 + 12*k*yt2 - 6*yt4 + 4*k*ytau2 - 2*ytau4;
 
  betam21 = (-9*g2)/2 - (3*gp2)/2 + 12*k + 6*yb2 + 6*yt2 + 2*ytau2;
 
  gamma1 = (-9*g2)/4 - (3*gp2)/4 + 3*yb2 + 3*yt2 + ytau2;

  beta_g3 = kappa*betag31;
  beta_g = kappa*betag1;
  beta_gp = kappa*betagp1;
  beta_yt = kappa*betayt1;
  beta_yb = 0.0;
  beta_ytau = 0.0;
/*   beta_yb = kappa*betayb1; */
/*   beta_ytau = kappa*betaytau1; */
  beta_k = kappa*betak1;
  /* Multiply next by m2 at very end: */
  beta_m2 = kappa*betam21;
  gamma = kappa*gamma1;

  if (loopOrder > 1) {

    betag32 = (9*g2*g33)/2 - 26*g35 + (11*g33*gp2)/6 - 2*g33*yb2 -
      2*g33*yt2;

    betag2 = (35*g5)/6 + 12*g3_*g32 + (3*g3_*gp2)/2 - (3*g3_*yb2)/2 -
      (3*g3_*yt2)/2 - (g3_*ytau2)/2;

    betagp2 = (9*g2*gp3)/2 + (44*g32*gp3)/3 + (199*gp5)/18 -
      (5*gp3*yb2)/6 - (17*gp3*yt2)/6 - (5*gp3*ytau2)/2;

    betayt2 = (-23*g4*yt)/4 + 9*g2*g32*yt - 108*g34*yt - (3*g2*gp2*yt)/4 +
      (19*g32*gp2*yt)/9 + (1187*gp4*yt)/216 + 6*k2*yt +
      (99*g2*yb2*yt)/16 + 4*g32*yb2*yt + (7*gp2*yb2*yt)/48 -
      (yb4*yt)/4 + (225*g2*yt3)/16 + 36*g32*yt3 + (131*gp2*yt3)/16 -
      12*k*yt3 - (11*yb2*yt3)/4 - 12*yt5 + (15*g2*yt*ytau2)/8 +
      (25*gp2*yt*ytau2)/8 + (5*yb2*yt*ytau2)/4 - (9*yt3*ytau2)/4 -
      (9*yt*ytau4)/4;

/*     betayb2 = (-23*g4*yb)/4 + 9*g2*g32*yb - 108*g34*yb - (9*g2*gp2*yb)/4 + */
/*       (31*g32*gp2*yb)/9 - (127*gp4*yb)/216 + 6*k2*yb + (225*g2*yb3)/16 + */
/*       36*g32*yb3 + (79*gp2*yb3)/16 - 12*k*yb3 - 12*yb5 + */
/*       (99*g2*yb*yt2)/16 + 4*g32*yb*yt2 + (91*gp2*yb*yt2)/48 - */
/*       (11*yb3*yt2)/4 - (yb*yt4)/4 + (15*g2*yb*ytau2)/8 + */
/*       (25*gp2*yb*ytau2)/8 - (9*yb3*ytau2)/4 + (5*yb*yt2*ytau2)/4 - */
/*       (9*yb*ytau4)/4; */

/*     betaytau2 = (-23*g4*ytau)/4 + (9*g2*gp2*ytau)/4 + (457*gp4*ytau)/24 + */
/*       6*k2*ytau + (45*g2*yb2*ytau)/8 + 20*g32*yb2*ytau + */
/*       (25*gp2*yb2*ytau)/24 - (27*yb4*ytau)/4 + (45*g2*yt2*ytau)/8 + */
/*       20*g32*yt2*ytau + (85*gp2*yt2*ytau)/24 + (3*yb2*yt2*ytau)/2 - */
/*       (27*yt4*ytau)/4 + (165*g2*ytau3)/16 + (179*gp2*ytau3)/16 - */
/*       12*k*ytau3 - (27*yb2*ytau3)/4 - (27*yt2*ytau3)/4 - 3*ytau5; */

    betak2 = (305*g6)/16 - (289*g4*gp2)/48 - (559*g2*gp4)/48 -
      (379*gp6)/48 - (73*g4*k)/8 + (39*g2*gp2*k)/4 + (629*gp4*k)/24 +
      108*g2*k2 + 36*gp2*k2 - 312*k3 - (9*g4*yb2)/4 +
      (9*g2*gp2*yb2)/2 + (5*gp4*yb2)/4 + (45*g2*k*yb2)/2 +
      80*g32*k*yb2 + (25*gp2*k*yb2)/6 - 144*k2*yb2 - 32*g32*yb4 +
      (4*gp2*yb4)/3 - 3*k*yb4 + 30*yb6 - (9*g4*yt2)/4 +
      (21*g2*gp2*yt2)/2 - (19*gp4*yt2)/4 + (45*g2*k*yt2)/2 +
      80*g32*k*yt2 + (85*gp2*k*yt2)/6 - 144*k2*yt2 - 42*k*yb2*yt2 -
      6*yb4*yt2 - 32*g32*yt4 - (8*gp2*yt4)/3 - 3*k*yt4 - 6*yb2*yt4 +
      30*yt6 - (3*g4*ytau2)/4 + (11*g2*gp2*ytau2)/2 -
      (25*gp4*ytau2)/4 + (15*g2*k*ytau2)/2 + (25*gp2*k*ytau2)/2 -
      48*k2*ytau2 - 4*gp2*ytau4 - k*ytau4 + 10*ytau6;
 
    betam22 = (-145*g4)/16 + (15*g2*gp2)/8 + (557*gp4)/48 + 72*g2*k +
      24*gp2*k - 60*k2 + (45*g2*yb2)/4 + 40*g32*yb2 +
      (25*gp2*yb2)/12 - 72*k*yb2 - (27*yb4)/2 + (45*g2*yt2)/4 +
      40*g32*yt2 + (85*gp2*yt2)/12 - 72*k*yt2 - 21*yb2*yt2 -
      (27*yt4)/2 + (15*g2*ytau2)/4 + (25*gp2*ytau2)/4 - 24*k*ytau2 -
      (9*ytau4)/2;
 
    gamma2 = (-271*g4)/32 + (9*g2*gp2)/16 + (431*gp4)/96 + 6*k2 +
      (45*g2*yb2)/8 + 20*g32*yb2 + (25*gp2*yb2)/24 - (27*yb4)/4 +
      (45*g2*yt2)/8 + 20*g32*yt2 + (85*gp2*yt2)/24 + (3*yb2*yt2)/2 -
      (27*yt4)/4 + (15*g2*ytau2)/8 + (25*gp2*ytau2)/8 - (9*ytau4)/4;

    beta_g3 += kappa2*betag32;
    beta_g += kappa2*betag2;
    beta_gp += kappa2*betagp2;
    beta_yt += kappa2*betayt2;
/*     beta_yb += kappa2*betayb2; */
/*     beta_ytau += kappa2*betaytau2; */
    beta_k += kappa2*betak2;
    /* Multiply next by m2 at very end: */
    beta_m2 += kappa2*betam22;
    gamma += kappa2*gamma2;
  }
  if (loopOrder > 2) {

    betag33 = (109*g4*g33)/8 + 21*g2*g35 + (65*g33*g34)/2 - (g2*g33*gp2)/8 +
      (77*g35*gp2)/9 - (2615*g33*gp4)/216 - (93*g2*g33*yb2)/8 -
      40*g35*yb2 - (89*g33*gp2*yb2)/24 + 15*g33*yb4 -
      (93*g2*g33*yt2)/8 - 40*g35*yt2 - (101*g33*gp2*yt2)/24 +
      18*g33*yb2*yt2 + 15*g33*yt4 + (7*g33*yb2*ytau2)/2 +
      (7*g33*yt2*ytau2)/2;

    betag3 = (324953*g5*g2)/1728 + 39*g5*g32 + 81*g3_*g34 + (291*g5*gp2)/32 -
      (g3_*g32*gp2)/3 - (5597*g3_*gp4)/576 + (3*g5*k)/2 + (g3_*gp2*k)/2 -
      3*g3_*k2 - (729*g5*yb2)/32 - 7*g3_*g32*yb2 -
      (533*g3_*gp2*yb2)/96 + (147*g3_*yb4)/16 - (729*g5*yt2)/32 -
      7*g3_*g32*yt2 - (593*g3_*gp2*yt2)/96 + (117*g3_*yb2*yt2)/8 +
      (147*g3_*yt4)/16 - (243*g5*ytau2)/32 - (85*g3_*gp2*ytau2)/32 +
      (15*g3_*yb2*ytau2)/4 + (15*g3_*yt2*ytau2)/4 + (29*g3_*ytau4)/16;

    betagp3 = (1315*g4*gp3)/64 - g2*g32*gp3 + 99*g34*gp3 +
      (205*g2*gp5)/96 - (137*g32*gp5)/27 - (388613*gp4*gp3)/5184 +
      (3*g2*gp3*k)/2 + (3*gp5*k)/2 - 3*gp3*k2 - (437*g2*gp3*yb2)/32 -
      (17*g32*gp3*yb2)/3 - (1267*gp5*yb2)/288 + (95*gp3*yb4)/16 -
      (785*g2*gp3*yt2)/32 - (29*g32*gp3*yt2)/3 - (2827*gp5*yt2)/288 +
      (123*gp3*yb2*yt2)/8 + (315*gp3*yt4)/16 - (543*g2*gp3*ytau2)/32 -
      (281*gp5*ytau2)/32 + (157*gp3*yb2*ytau2)/12 +
      (199*gp3*yt2*ytau2)/12 + (153*gp3*ytau4)/16;

    betayt3 = (455*g6*yt)/576 + (435*g4*g32*yt)/4 + (987*g2*g34*yt)/4 -
      (4166*g36*yt)/3 + (273*g4*gp2*yt)/64 - (107*g2*g32*gp2*yt)/4 +
      (1633*g34*gp2*yt)/36 + (2045*g2*gp4*yt)/192 +
      (2047*g32*gp4*yt)/54 + (763523*gp6*yt)/5184 - (171*g4*k*yt)/16 +
      (39*g2*gp2*k*yt)/8 - (121*gp4*k*yt)/16 + 45*g2*k2*yt +
      15*gp2*k2*yt - 36*k3*yt + (10341*g4*yb2*yt)/256 -
      (27*g2*g32*yb2*yt)/2 - (305*g34*yb2*yt)/2 +
      (1245*g2*gp2*yb2*yt)/128 - (457*g32*gp2*yb2*yt)/18 -
      (40673*gp4*yb2*yt)/6912 - (291*k2*yb2*yt)/4 -
      (2283*g2*yb4*yt)/32 + 82*g32*yb4*yt - (959*gp2*yb4*yt)/96 +
      15*k*yb4*yt + (477*yb6*yt)/16 + (32391*g4*yt3)/256 -
      168*g2*g32*yt3 + (3827*g34*yt3)/6 + (2699*g2*gp2*yt3)/128 -
      42*g32*gp2*yt3 - (458179*gp4*yt3)/6912 - (135*g2*k*yt3)/2 +
      16*g32*k*yt3 - (127*gp2*k*yt3)/6 + (15*k2*yt3)/4 -
      (2307*g2*yb2*yt3)/32 + 27*g32*yb2*yt3 - (461*gp2*yb2*yt3)/32 +
      93*k*yb2*yt3 + (825*yb4*yt3)/8 - (1593*g2*yt5)/16 -
      157*g32*yt5 - (2437*gp2*yt5)/48 + 198*k*yt5 + (739*yb2*yt5)/16 +
      (339*yt7)/8 + (1113*g4*yt*ytau2)/128 - (347*g2*gp2*yt*ytau2)/64 -
      (48295*gp4*yt*ytau2)/1152 - (45*k2*yt*ytau2)/2 -
      (153*g2*yb2*yt*ytau2)/8 - (43*g32*yb2*yt*ytau2)/6 +
      (491*gp2*yb2*yt*ytau2)/72 + 22*yb4*yt*ytau2 -
      (81*g2*yt3*ytau2)/4 + (5*g32*yt3*ytau2)/2 - 21*gp2*yt3*ytau2 +
      30*k*yt3*ytau2 + (7*yb2*yt3*ytau2)/2 + (21*yt5*ytau2)/2 -
      (315*g2*yt*ytau4)/16 - (45*gp2*yt*ytau4)/16 + 15*k*yt*ytau4 +
      (53*yb2*yt*ytau4)/4 + (207*yt3*ytau4)/8 + (71*yt*ytau6)/16 +
      (1125*g6*yt*Zeta3)/8 - 108*g4*g32*yt*Zeta3 - 144*g2*g34*yt*Zeta3 +
      640*g36*yt*Zeta3 - (81*g4*gp2*yt*Zeta3)/8 -
      (176*g34*gp2*yt*Zeta3)/3 - (153*g2*gp4*yt*Zeta3)/8 -
      (748*g32*gp4*yt*Zeta3)/9 - (13073*gp6*yt*Zeta3)/216 -
      (225*g4*yb2*yt*Zeta3)/8 - 108*g2*g32*yb2*yt*Zeta3 -
      44*g34*yb2*yt*Zeta3 + (9*g2*gp2*yb2*yt*Zeta3)/2 -
      (28*g32*gp2*yb2*yt*Zeta3)/3 - (199*gp4*yb2*yt*Zeta3)/72 +
      (63*g2*yb4*yt*Zeta3)/2 - 64*g32*yb4*yt*Zeta3 +
      (19*gp2*yb4*yt*Zeta3)/6 + (9*yb6*yt*Zeta3)/2 -
      (729*g4*yt3*Zeta3)/8 + 180*g2*g32*yt3*Zeta3 - 228*g34*yt3*Zeta3 +
      (123*g2*gp2*yt3*Zeta3)/4 + 60*g32*gp2*yt3*Zeta3 -
      (31*gp4*yt3*Zeta3)/24 - (9*g2*yb2*yt3*Zeta3)/2 -
      32*g32*yb2*yt3*Zeta3 + (5*gp2*yb2*yt3*Zeta3)/6 -
      48*yb4*yt3*Zeta3 + (27*yt7*Zeta3)/2 - (81*g4*yt*ytau2*Zeta3)/4 -
      3*g2*gp2*yt*ytau2*Zeta3 - (269*gp4*yt*ytau2*Zeta3)/12 +
      9*g2*yb2*yt*ytau2*Zeta3 - 9*gp2*yb2*yt*ytau2*Zeta3 -
      9*g2*yt3*ytau2*Zeta3 + 8*gp2*yt3*ytau2*Zeta3 +
      9*g2*yt*ytau4*Zeta3 - 9*gp2*yt*ytau4*Zeta3 + 3*yt*ytau6*Zeta3;

/*     betayb3 = (455*g6*yb)/576 + (435*g4*g32*yb)/4 + (987*g2*g34*yb)/4 - */
/*       (4166*g36*yb)/3 - (211*g4*gp2*yb)/64 - (51*g2*g32*gp2*yb)/4 + */
/*       (4165*g34*gp2*yb)/36 + (3565*g2*gp4*yb)/192 - */
/*       (337*g32*gp4*yb)/27 + (93241*gp6*yb)/1728 - (171*g4*k*yb)/16 - */
/*       (9*g2*gp2*k*yb)/8 - (25*gp4*k*yb)/16 + 45*g2*k2*yb + */
/*       15*gp2*k2*yb - 36*k3*yb + (32391*g4*yb3)/256 - 168*g2*g32*yb3 + */
/*       (3827*g34*yb3)/6 + (2831*g2*gp2*yb3)/128 - 30*g32*gp2*yb3 - */
/*       (209659*gp4*yb3)/6912 - (135*g2*k*yb3)/2 + 16*g32*k*yb3 - */
/*       (139*gp2*k*yb3)/6 + (15*k2*yb3)/4 - (1593*g2*yb5)/16 - */
/*       157*g32*yb5 - (1981*gp2*yb5)/48 + 198*k*yb5 + (339*yb7)/8 + */
/*       (10341*g4*yb*yt2)/256 - (27*g2*g32*yb*yt2)/2 - */
/*       (305*g34*yb*yt2)/2 + (1089*g2*gp2*yb*yt2)/128 - */
/*       (805*g32*gp2*yb*yt2)/18 - (104729*gp4*yb*yt2)/6912 - */
/*       (291*k2*yb*yt2)/4 - (2307*g2*yb3*yt2)/32 + 27*g32*yb3*yt2 - */
/*       (1401*gp2*yb3*yt2)/32 + 93*k*yb3*yt2 + (739*yb5*yt2)/16 - */
/*       (2283*g2*yb*yt4)/32 + 82*g32*yb*yt4 - (121*gp2*yb*yt4)/32 + */
/*       15*k*yb*yt4 + (825*yb3*yt4)/8 + (477*yb*yt6)/16 + */
/*       (3033*g4*yb*ytau2)/128 - (411*g2*gp2*yb*ytau2)/64 - */
/*       (45239*gp4*yb*ytau2)/1152 - (45*k2*yb*ytau2)/2 - */
/*       (81*g2*yb3*ytau2)/4 + (5*g32*yb3*ytau2)/2 - */
/*       (137*gp2*yb3*ytau2)/6 + 30*k*yb3*ytau2 + (21*yb5*ytau2)/2 - */
/*       (153*g2*yb*yt2*ytau2)/8 - (43*g32*yb*yt2*ytau2)/6 + */
/*       (293*gp2*yb*yt2*ytau2)/72 + (7*yb3*yt2*ytau2)/2 + */
/*       22*yb*yt4*ytau2 - (315*g2*yb*ytau4)/16 - (45*gp2*yb*ytau4)/16 + */
/*       15*k*yb*ytau4 + (207*yb3*ytau4)/8 + (53*yb*yt2*ytau4)/4 + */
/*       (71*yb*ytau6)/16 + (1125*g6*yb*Zeta3)/8 - 108*g4*g32*yb*Zeta3 - */
/*       144*g2*g34*yb*Zeta3 + 640*g36*yb*Zeta3 - (81*g4*gp2*yb*Zeta3)/8 - */
/*       (176*g34*gp2*yb*Zeta3)/3 - (45*g2*gp4*yb*Zeta3)/8 - */
/*       (220*g32*gp4*yb*Zeta3)/9 - (3845*gp6*yb*Zeta3)/216 - */
/*       (729*g4*yb3*Zeta3)/8 + 180*g2*g32*yb3*Zeta3 - 228*g34*yb3*Zeta3 - */
/*       3*g2*gp2*yb3*Zeta3 + 44*g32*gp2*yb3*Zeta3 - */
/*       (19*gp4*yb3*Zeta3)/8 + (27*yb7*Zeta3)/2 - (225*g4*yb*yt2*Zeta3)/8 - */
/*       108*g2*g32*yb*yt2*Zeta3 - 44*g34*yb*yt2*Zeta3 + */
/*       (63*g2*gp2*yb*yt2*Zeta3)/4 + (20*g32*gp2*yb*yt2*Zeta3)/3 - */
/*       (13*gp4*yb*yt2*Zeta3)/72 - (9*g2*yb3*yt2*Zeta3)/2 - */
/*       32*g32*yb3*yt2*Zeta3 + (77*gp2*yb3*yt2*Zeta3)/6 + */
/*       (63*g2*yb*yt4*Zeta3)/2 - 64*g32*yb*yt4*Zeta3 - */
/*       (17*gp2*yb*yt4*Zeta3)/6 - 48*yb3*yt4*Zeta3 + (9*yb*yt6*Zeta3)/2 - */
/*       (99*g4*yb*ytau2*Zeta3)/4 + 18*g2*gp2*yb*ytau2*Zeta3 + */
/*       (39*gp4*yb*ytau2*Zeta3)/4 - 9*g2*yb3*ytau2*Zeta3 + */
/*       7*gp2*yb3*ytau2*Zeta3 + 9*g2*yb*yt2*ytau2*Zeta3 - */
/*       6*gp2*yb*yt2*ytau2*Zeta3 + 9*g2*yb*ytau4*Zeta3 - */
/*       9*gp2*yb*ytau4*Zeta3 + 3*yb*ytau6*Zeta3; */

/*     betaytau3 = (455*g6*ytau)/576 + (351*g4*g32*ytau)/4 + */
/*       (981*g4*gp2*ytau)/64 + (771*g2*gp4*ytau)/64 + */
/*       (803*g32*gp4*ytau)/4 + (607261*gp6*ytau)/1728 - (171*g4*k*ytau)/16 + */
/*       (87*g2*gp2*k*ytau)/8 - (345*gp4*k*ytau)/16 + 45*g2*k2*ytau + */
/*       15*gp2*k2*ytau - 36*k3*ytau + (9099*g4*yb2*ytau)/128 - */
/*       (489*g2*g32*yb2*ytau)/4 + (622*g34*yb2*ytau)/3 + */
/*       (1823*g2*gp2*yb2*ytau)/64 - (991*g32*gp2*yb2*ytau)/36 - */
/*       (54511*gp4*yb2*ytau)/3456 - (135*k2*yb2*ytau)/2 - */
/*       (1161*g2*yb4*ytau)/16 + (15*g32*yb4*ytau)/2 - */
/*       (411*gp2*yb4*ytau)/16 + 45*k*yb4*ytau + (789*yb6*ytau)/16 + */
/*       (3339*g4*yt2*ytau)/128 - (489*g2*g32*yt2*ytau)/4 + */
/*       (622*g34*yt2*ytau)/3 + (1139*g2*gp2*yt2*ytau)/64 - */
/*       (2419*g32*gp2*yt2*ytau)/36 - (167815*gp4*yt2*ytau)/3456 - */
/*       (135*k2*yt2*ytau)/2 - (387*g2*yb2*yt2*ytau)/8 + */
/*       57*g32*yb2*yt2*ytau - (139*gp2*yb2*yt2*ytau)/8 + */
/*       (831*yb4*yt2*ytau)/16 - (1161*g2*yt4*ytau)/16 + */
/*       (15*g32*yt4*ytau)/2 - (319*gp2*yt4*ytau)/16 + 45*k*yt4*ytau + */
/*       (831*yb2*yt4*ytau)/16 + (789*yt6*ytau)/16 + (20259*g4*ytau3)/256 - */
/*       (909*g2*gp2*ytau3)/128 - (18805*gp4*ytau3)/256 - */
/*       (135*g2*k*ytau3)/2 - (33*gp2*k*ytau3)/2 + (195*k2*ytau3)/4 - */
/*       (135*g2*yb2*ytau3)/4 - 96*g32*yb2*ytau3 - */
/*       (29*gp2*yb2*ytau3)/4 + 90*k*yb2*ytau3 + (279*yb4*ytau3)/8 - */
/*       (135*g2*yt2*ytau3)/4 - 96*g32*yt2*ytau3 - */
/*       (77*gp2*yt2*ytau3)/4 + 90*k*yt2*ytau3 - (87*yb2*yt2*ytau3)/4 + */
/*       (279*yt4*ytau3)/8 - (531*g2*ytau5)/16 - (765*gp2*ytau5)/16 + */
/*       108*k*ytau5 + 9*yb2*ytau5 + 9*yt2*ytau5 - 10*ytau7 + */
/*       (1125*g6*ytau*Zeta3)/8 - 108*g4*g32*ytau*Zeta3 - */
/*       (81*g4*gp2*ytau*Zeta3)/8 - (405*g2*gp4*ytau*Zeta3)/8 - */
/*       220*g32*gp4*ytau*Zeta3 - (3845*gp6*ytau*Zeta3)/24 - */
/*       (297*g4*yb2*ytau*Zeta3)/4 + 108*g2*g32*yb2*ytau*Zeta3 - */
/*       24*g34*yb2*ytau*Zeta3 - 9*g2*gp2*yb2*ytau*Zeta3 + */
/*       20*g32*gp2*yb2*ytau*Zeta3 - (29*gp4*yb2*ytau*Zeta3)/12 + */
/*       27*g2*yb4*ytau*Zeta3 - 72*g32*yb4*ytau*Zeta3 + */
/*       9*gp2*yb4*ytau*Zeta3 + 9*yb6*ytau*Zeta3 - (243*g4*yt2*ytau*Zeta3)/ */
/*       4 + 108*g2*g32*yt2*ytau*Zeta3 - 24*g34*yt2*ytau*Zeta3 - */
/*       (99*g2*gp2*yt2*ytau*Zeta3)/2 + 68*g32*gp2*yt2*ytau*Zeta3 - */
/*       (1157*gp4*yt2*ytau*Zeta3)/12 - 48*g32*yb2*yt2*ytau*Zeta3 + */
/*       8*gp2*yb2*yt2*ytau*Zeta3 + 27*g2*yt4*ytau*Zeta3 - */
/*       72*g32*yt4*ytau*Zeta3 - 3*gp2*yt4*ytau*Zeta3 + 9*yt6*ytau*Zeta3 - */
/*       (333*g4*ytau3*Zeta3)/8 + (117*g2*gp2*ytau3*Zeta3)/2 - */
/*       (75*gp4*ytau3*Zeta3)/8 - 27*g2*yb2*ytau3*Zeta3 + */
/*       72*g32*yb2*ytau3*Zeta3 - 3*gp2*yb2*ytau3*Zeta3 - */
/*       27*g2*yt2*ytau3*Zeta3 + 72*g32*yt2*ytau3*Zeta3 + */
/*       6*gp2*yt2*ytau3*Zeta3 + (15*ytau7*Zeta3)/2; */

    betak3 = (228259*g8)/1536 - (459*g6*g32)/4 - (165665*g6*gp2)/1728 -
      (153*g4*g32*gp2)/4 - (81509*g4*gp4)/1728 - (187*g2*g32*gp4)/4 -
      (237787*g2*gp6)/3456 - (187*g32*gp6)/4 - (51845*gp8)/512 +
      (58031*g6*k)/144 + 405*g4*g32*k + (6137*g4*gp2*k)/16 +
      (1549*g2*gp4*k)/4 + 165*g32*gp4*k + (88639*gp6*k)/216 -
      (1389*g4*k2)/4 - 666*g2*gp2*k2 - 836*gp4*k2 - 948*g2*k3 -
      316*gp2*k3 + 7176*k4 - (6849*g6*yb2)/128 + (651*g4*g32*yb2)/4 +
      (6099*g4*gp2*yb2)/128 + (233*g2*g32*gp2*yb2)/2 +
      (7603*g2*gp4*yb2)/128 + (683*g32*gp4*yb2)/12 +
      (48523*gp6*yb2)/1152 - (6957*g4*k*yb2)/32 - 489*g2*g32*k*yb2 +
      (2488*g34*k*yb2)/3 - (3009*g2*gp2*k*yb2)/16 -
      (991*g32*gp2*k*yb2)/9 - (149623*gp4*k*yb2)/864 +
      (639*g2*k2*yb2)/2 - 2448*g32*k2*yb2 + (417*gp2*k2*yb2)/2 +
      1746*k3*yb2 + (9909*g4*yb4)/64 - 31*g2*g32*yb4 -
      (532*g34*yb4)/3 - (3239*g2*gp2*yb4)/96 - (641*g32*gp2*yb4)/9 -
      (104383*gp4*yb4)/1728 - (4977*g2*k*yb4)/4 + 1790*g32*k*yb4 -
      (5737*gp2*k*yb4)/12 + 1719*k2*yb4 + (3411*g2*yb6)/16 -
      76*g32*yb6 + (5111*gp2*yb6)/48 + (117*k*yb6)/4 - (1599*yb8)/4 -
      (6849*g6*yt2)/128 + (651*g4*g32*yt2)/4 + (3487*g4*gp2*yt2)/128 +
      (249*g2*g32*gp2*yt2)/2 + (25441*g2*gp4*yt2)/384 +
      (587*g32*gp4*yt2)/12 + (125503*gp6*yt2)/1152 -
      (6957*g4*k*yt2)/32 - 489*g2*g32*k*yt2 + (2488*g34*k*yt2)/3 -
      (6509*g2*gp2*k*yt2)/16 - (2419*g32*gp2*k*yt2)/9 -
      (203887*gp4*k*yt2)/864 + (639*g2*k2*yt2)/2 - 2448*g32*k2*yt2 -
      (195*gp2*k2*yt2)/2 + 1746*k3*yt2 - (2655*g4*yb2*yt2)/32 -
      16*g2*g32*yb2*yt2 + 384*g34*yb2*yt2 + (1001*g2*gp2*yb2*yt2)/
      48 - (709*gp4*yb2*yt2)/32 - (531*g2*k*yb2*yt2)/2 +
      164*g32*k*yb2*yt2 - (929*gp2*k*yb2*yt2)/6 + 234*k2*yb2*yt2 +
      (477*g2*yb4*yt2)/16 - 4*g32*yb4*yt2 - (2299*gp2*yb4*yt2)/48 +
      (6399*k*yb4*yt2)/4 - (717*yb6*yt2)/4 + (9909*g4*yt4)/64 -
      31*g2*g32*yt4 - (532*g34*yt4)/3 - (1079*g2*gp2*yt4)/96 +
      (931*g32*gp2*yt4)/9 + (67793*gp4*yt4)/1728 - (4977*g2*k*yt4)/4 +
      1790*g32*k*yt4 - (2485*gp2*k*yt4)/12 + 1719*k2*yt4 +
      (477*g2*yb2*yt4)/16 - 4*g32*yb2*yt4 + (1337*gp2*yb2*yt4)/48 +
      (6399*k*yb2*yt4)/4 + (3411*g2*yt6)/16 - 76*g32*yt6 +
      (3467*gp2*yt6)/48 + (117*k*yt6)/4 - (717*yb2*yt6)/4 -
      (1599*yt8)/4 - (2283*g6*ytau2)/128 + (1449*g4*gp2*ytau2)/128 +
      (6017*g2*gp4*ytau2)/128 + (10969*gp6*ytau2)/128 -
      (2319*g4*k*ytau2)/32 - (3771*g2*gp2*k*ytau2)/16 -
      (4903*gp4*k*ytau2)/32 + (213*g2*k2*ytau2)/2 -
      (541*gp2*k2*ytau2)/2 + 582*k3*ytau2 + (9*g4*yb2*ytau2)/4 -
      (5*g2*gp2*yb2*ytau2)/2 + (41*gp4*yb2*ytau2)/12 -
      54*g2*k*yb2*ytau2 - 18*gp2*k*yb2*ytau2 - 432*k2*yb2*ytau2 +
      480*k*yb4*ytau2 - (297*yb6*ytau2)/4 + (9*g4*yt2*ytau2)/4 +
      (29*g2*gp2*yt2*ytau2)/2 + (701*gp4*yt2*ytau2)/12 -
      54*g2*k*yt2*ytau2 - 18*gp2*k*yt2*ytau2 - 432*k2*yt2*ytau2 +
      42*k*yb2*yt2*ytau2 + (45*yb4*yt2*ytau2)/4 + 480*k*yt4*ytau2 +
      (45*yb2*yt4*ytau2)/4 - (297*yt6*ytau2)/4 + (3255*g4*ytau4)/64 -
      (15*g2*gp2*ytau4)/32 + (7777*gp4*ytau4)/64 -
      (1587*g2*k*ytau4)/4 + (507*gp2*k*ytau4)/4 + 717*k2*ytau4 +
      480*k*yb2*ytau4 - 144*yb4*ytau4 + 480*k*yt2*ytau4 +
      24*yb2*yt2*ytau4 - 144*yt4*ytau4 + (1137*g2*ytau6)/16 +
      (135*gp2*ytau6)/16 - (1241*k*ytau6)/4 - (297*yb2*ytau6)/4 -
      (297*yt2*ytau6)/4 - (143*ytau8)/4 - (20061*g8*Zeta3)/64 +
      108*g6*g32*Zeta3 - (405*g6*gp2*Zeta3)/16 + 36*g4*g32*gp2*Zeta3 +
      (2217*g4*gp4*Zeta3)/32 + 44*g2*g32*gp4*Zeta3 +
      (2177*g2*gp6*Zeta3)/48 + 44*g32*gp6*Zeta3 + (12457*gp8*Zeta3)/192 +
      (4419*g6*k*Zeta3)/4 - 432*g4*g32*k*Zeta3 - (393*g4*gp2*k*Zeta3)/4 -
      (147*g2*gp4*k*Zeta3)/4 - 176*g32*gp4*k*Zeta3 -
      (1493*gp6*k*Zeta3)/12 - 1026*g4*k2*Zeta3 - 324*g2*gp2*k2*Zeta3 -
      162*gp4*k2*Zeta3 + 144*g2*k3*Zeta3 + 48*gp2*k3*Zeta3 +
      4032*k4*Zeta3 + (297*g6*yb2*Zeta3)/2 - 108*g4*g32*yb2*Zeta3 +
      18*g4*gp2*yb2*Zeta3 - 72*g2*g32*gp2*yb2*Zeta3 +
      9*g2*gp4*yb2*Zeta3 - 36*g32*gp4*yb2*Zeta3 +
      (5*gp6*yb2*Zeta3)/2 - 351*g4*k*yb2*Zeta3 +
      432*g2*g32*k*yb2*Zeta3 - 96*g34*k*yb2*Zeta3 +
      24*g2*gp2*k*yb2*Zeta3 + 80*g32*gp2*k*yb2*Zeta3 -
      (47*gp4*k*yb2*Zeta3)/3 - 864*g2*k2*yb2*Zeta3 +
      2304*g32*k2*yb2*Zeta3 - 384*gp2*k2*yb2*Zeta3 -
      (819*g4*yb4*Zeta3)/8 + 48*g2*g32*yb4*Zeta3 + 64*g34*yb4*Zeta3 -
      (311*g2*gp2*yb4*Zeta3)/4 + (272*g32*gp2*yb4*Zeta3)/3 -
      (2035*gp4*yb4*Zeta3)/72 + 1026*g2*k*yb4*Zeta3 -
      2592*g32*k*yb4*Zeta3 + 498*gp2*k*yb4*Zeta3 + 1512*k2*yb4*Zeta3 -
      54*g2*yb6*Zeta3 + 480*g32*yb6*Zeta3 - 50*gp2*yb6*Zeta3 -
      396*k*yb6*Zeta3 - 72*yb8*Zeta3 + (297*g6*yt2*Zeta3)/2 -
      108*g4*g32*yt2*Zeta3 + (27*g4*gp2*yt2*Zeta3)/2 -
      72*g2*g32*gp2*yt2*Zeta3 - 6*g2*gp4*yt2*Zeta3 -
      36*g32*gp4*yt2*Zeta3 - 5*gp6*yt2*Zeta3 - 351*g4*k*yt2*Zeta3 +
      432*g2*g32*k*yt2*Zeta3 - 96*g34*k*yt2*Zeta3 +
      354*g2*gp2*k*yt2*Zeta3 + 272*g32*gp2*k*yt2*Zeta3 -
      (449*gp4*k*yt2*Zeta3)/3 - 864*g2*k2*yt2*Zeta3 +
      2304*g32*k2*yt2*Zeta3 - 96*gp2*k2*yt2*Zeta3 +
      117*g4*yb2*yt2*Zeta3 + 192*g2*g32*yb2*yt2*Zeta3 +
      31*g2*gp2*yb2*yt2*Zeta3 - 2*gp4*yb2*yt2*Zeta3 +
      108*g2*k*yb2*yt2*Zeta3 - 192*g32*k*yb2*yt2*Zeta3 -
      4*gp2*k*yb2*yt2*Zeta3 - 1728*k2*yb2*yt2*Zeta3 -
      96*g32*yb4*yt2*Zeta3 + 52*gp2*yb4*yt2*Zeta3 +
      288*k*yb4*yt2*Zeta3 - 72*yb6*yt2*Zeta3 - (819*g4*yt4*Zeta3)/8 +
      48*g2*g32*yt4*Zeta3 + 64*g34*yt4*Zeta3 - (743*g2*gp2*yt4*Zeta3)/
      4 - (112*g32*gp2*yt4*Zeta3)/3 + (2957*gp4*yt4*Zeta3)/72 +
      1026*g2*k*yt4*Zeta3 - 2592*g32*k*yt4*Zeta3 + 114*gp2*k*yt4*Zeta3 +
      1512*k2*yt4*Zeta3 - 96*g32*yb2*yt4*Zeta3 -
      56*gp2*yb2*yt4*Zeta3 + 288*k*yb2*yt4*Zeta3 + 144*yb4*yt4*Zeta3 -
      54*g2*yt6*Zeta3 + 480*g32*yt6*Zeta3 + 34*gp2*yt6*Zeta3 -
      396*k*yt6*Zeta3 - 72*yb2*yt6*Zeta3 - 72*yt8*Zeta3 +
      (99*g6*ytau2*Zeta3)/2 - 3*g4*gp2*ytau2*Zeta3 -
      15*g2*gp4*ytau2*Zeta3 - (15*gp6*ytau2*Zeta3)/2 -
      117*g4*k*ytau2*Zeta3 + 252*g2*gp2*k*ytau2*Zeta3 -
      123*gp4*k*ytau2*Zeta3 - 288*g2*k2*ytau2*Zeta3 +
      192*gp2*k2*ytau2*Zeta3 - (273*g4*ytau4*Zeta3)/8 -
      (381*g2*gp2*ytau4*Zeta3)/4 + (375*gp4*ytau4*Zeta3)/8 +
      342*g2*k*ytau4*Zeta3 - 234*gp2*k*ytau4*Zeta3 +
      504*k2*ytau4*Zeta3 - 18*g2*ytau6*Zeta3 + 66*gp2*ytau6*Zeta3 -
      132*k*ytau6*Zeta3 - 24*ytau8*Zeta3;

    betam23 = (49553*g6)/288 + (405*g4*g32)/2 + (3699*g4*gp2)/32 +
      (1713*g2*gp4)/16 + (165*g32*gp4)/2 + (4357*gp6)/27 +
      (4167*g4*k)/16 - (1701*g2*gp2*k)/8 - (5157*gp4*k)/16 - 126*g2*k2 -
      42*gp2*k2 + 2052*k3 - (3789*g4*yb2)/64 - (489*g2*g32*yb2)/2 +
      (1244*g34*yb2)/3 - (865*g2*gp2*yb2)/32 - (991*g32*gp2*yb2)/18 -
      (101527*gp4*yb2)/1728 + (567*g2*k*yb2)/4 - 1224*g32*k*yb2 +
      (393*gp2*k*yb2)/4 + 297*k2*yb2 - (3177*g2*yb4)/8 + 447*g32*yb4 -
      (1067*gp2*yb4)/8 + (351*k*yb4)/2 + (1605*yb6)/8 -
      (3789*g4*yt2)/64 - (489*g2*g32*yt2)/2 + (1244*g34*yt2)/3 -
      (3277*g2*gp2*yt2)/32 - (2419*g32*gp2*yt2)/18 -
      (214543*gp4*yt2)/1728 + (567*g2*k*yt2)/4 - 1224*g32*k*yt2 -
      (219*gp2*k*yt2)/4 + 297*k2*yt2 - (243*g2*yb2*yt2)/4 +
      82*g32*yb2*yt2 - (929*gp2*yb2*yt2)/12 - 315*k*yb2*yt2 +
      (4047*yb4*yt2)/8 - (3177*g2*yt4)/8 + 447*g32*yt4 -
      (431*gp2*yt4)/8 + (351*k*yt4)/2 + (4047*yb2*yt4)/8 +
      (1605*yt6)/8 - (1263*g4*ytau2)/64 - (2331*g2*gp2*ytau2)/32 -
      (6727*gp4*ytau2)/64 + (189*g2*k*ytau2)/4 - (549*gp2*k*ytau2)/4 +
      99*k2*ytau2 - 27*g2*yb2*ytau2 - 9*gp2*yb2*ytau2 -
      216*k*yb2*ytau2 + 144*yb4*ytau2 - 27*g2*yt2*ytau2 -
      9*gp2*yt2*ytau2 - 216*k*yt2*ytau2 + 21*yb2*yt2*ytau2 +
      144*yt4*ytau2 - (987*g2*ytau4)/8 + (291*gp2*ytau4)/8 +
      (261*k*ytau4)/2 + 144*yb2*ytau4 + 144*yt2*ytau4 - (233*ytau6)/8 +
      (2871*g6*Zeta3)/8 - 216*g4*g32*Zeta3 - (549*g4*gp2*Zeta3)/8 -
      (351*g2*gp4*Zeta3)/8 - 88*g32*gp4*Zeta3 - (1673*gp6*Zeta3)/24 -
      324*g4*k*Zeta3 + 72*g2*gp2*k*Zeta3 - 36*gp4*k*Zeta3 -
      216*g2*k2*Zeta3 - 72*gp2*k2*Zeta3 - (243*g4*yb2*Zeta3)/2 +
      216*g2*g32*yb2*Zeta3 - 48*g34*yb2*Zeta3 + 40*g32*gp2*yb2*Zeta3 -
      (35*gp4*yb2*Zeta3)/6 - 648*g2*k*yb2*Zeta3 + 1152*g32*k*yb2*Zeta3 -
      264*gp2*k*yb2*Zeta3 + 324*g2*yb4*Zeta3 - 720*g32*yb4*Zeta3 +
      144*gp2*yb4*Zeta3 + 432*k*yb4*Zeta3 + 90*yb6*Zeta3 -
      (243*g4*yt2*Zeta3)/2 + 216*g2*g32*yt2*Zeta3 - 48*g34*yt2*Zeta3 +
      117*g2*gp2*yt2*Zeta3 + 136*g32*gp2*yt2*Zeta3 -
      (149*gp4*yt2*Zeta3)/6 - 648*g2*k*yt2*Zeta3 +
      1152*g32*k*yt2*Zeta3 - 120*gp2*k*yt2*Zeta3 -
      54*g2*yb2*yt2*Zeta3 - 96*g32*yb2*yt2*Zeta3 -
      2*gp2*yb2*yt2*Zeta3 - 432*k*yb2*yt2*Zeta3 + 72*yb4*yt2*Zeta3 +
      324*g2*yt4*Zeta3 - 720*g32*yt4*Zeta3 + 24*gp2*yt4*Zeta3 +
      432*k*yt4*Zeta3 + 72*yb2*yt4*Zeta3 + 90*yt6*Zeta3 -
      (81*g4*ytau2*Zeta3)/2 + 90*g2*gp2*ytau2*Zeta3 -
      (15*gp4*ytau2*Zeta3)/2 - 216*g2*k*ytau2*Zeta3 +
      72*gp2*k*ytau2*Zeta3 + 108*g2*ytau4*Zeta3 - 72*gp2*ytau4*Zeta3 +
      144*k*ytau4*Zeta3 + 30*ytau6*Zeta3;
    
    gamma3 = (6785*g6)/576 + (405*g4*g32)/4 + (543*g4*gp2)/64 +
      (153*g2*gp4)/32 + (165*g32*gp4)/4 + (27053*gp6)/432 +
      (117*g4*k)/16 + (39*g2*gp2*k)/8 + (39*gp4*k)/16 + 45*g2*k2 +
      15*gp2*k2 - 36*k3 + (4275*g4*yb2)/128 - (489*g2*g32*yb2)/4 +
      (622*g34*yb2)/3 + (671*g2*gp2*yb2)/64 - (991*g32*gp2*yb2)/36 -
      (27799*gp4*yb2)/3456 - (135*k2*yb2)/2 - (1161*g2*yb4)/16 +
      (15*g32*yb4)/2 - (411*gp2*yb4)/16 + 45*k*yb4 + (789*yb6)/16 +
      (4275*g4*yt2)/128 - (489*g2*g32*yt2)/4 + (622*g34*yt2)/3 +
      (371*g2*gp2*yt2)/64 - (2419*g32*gp2*yt2)/36 -
      (144271*gp4*yt2)/3456 - (135*k2*yt2)/2 - (387*g2*yb2*yt2)/8 +
      57*g32*yb2*yt2 - (139*gp2*yb2*yt2)/8 + (831*yb4*yt2)/16 -
      (1161*g2*yt4)/16 + (15*g32*yt4)/2 - (319*gp2*yt4)/16 + 45*k*yt4 +
      (831*yb2*yt4)/16 + (789*yt6)/16 + (1425*g4*ytau2)/128 -
      (411*g2*gp2*ytau2)/64 - (5959*gp4*ytau2)/128 - (45*k2*ytau2)/2 -
      (27*g2*yb2*ytau2)/2 - (9*gp2*yb2*ytau2)/2 + 18*yb4*ytau2 -
      (27*g2*yt2*ytau2)/2 - (9*gp2*yt2*ytau2)/2 -
      (3*yb2*yt2*ytau2)/2 + 18*yt4*ytau2 - (315*g2*ytau4)/16 -
      (45*gp2*ytau4)/16 + 15*k*ytau4 + 18*yb2*ytau4 + 18*yt2*ytau4 +
      (71*ytau6)/16 + (1953*g6*Zeta3)/16 - 108*g4*g32*Zeta3 -
      (153*g4*gp2*Zeta3)/16 - (135*g2*gp4*Zeta3)/16 - 44*g32*gp4*Zeta3 -
      (1529*gp6*Zeta3)/48 - (27*g4*k*Zeta3)/2 - 9*g2*gp2*k*Zeta3 -
      (9*gp4*k*Zeta3)/2 - (189*g4*yb2*Zeta3)/4 + 108*g2*g32*yb2*Zeta3 -
      24*g34*yb2*Zeta3 - 9*g2*gp2*yb2*Zeta3 + 20*g32*gp2*yb2*Zeta3 -
      (29*gp4*yb2*Zeta3)/12 + 27*g2*yb4*Zeta3 - 72*g32*yb4*Zeta3 +
      9*gp2*yb4*Zeta3 + 9*yb6*Zeta3 - (189*g4*yt2*Zeta3)/4 +
      108*g2*g32*yt2*Zeta3 - 24*g34*yt2*Zeta3 +
      (27*g2*gp2*yt2*Zeta3)/2 + 68*g32*gp2*yt2*Zeta3 +
      (gp4*yt2*Zeta3)/12 - 48*g32*yb2*yt2*Zeta3 +
      8*gp2*yb2*yt2*Zeta3 + 27*g2*yt4*Zeta3 - 72*g32*yt4*Zeta3 -
      3*gp2*yt4*Zeta3 + 9*yt6*Zeta3 - (63*g4*ytau2*Zeta3)/4 +
      18*g2*gp2*ytau2*Zeta3 + (39*gp4*ytau2*Zeta3)/4 +
      9*g2*ytau4*Zeta3 - 9*gp2*ytau4*Zeta3 + 3*ytau6*Zeta3;

    beta_g3 += kappa3*betag33;
    beta_g += kappa3*betag3;
    beta_gp += kappa3*betagp3;
    beta_yt += kappa3*betayt3;
/*     beta_yb += kappa3*betayb3; */
/*     beta_ytau += kappa3*betaytau3; */
    beta_k += kappa3*betak3;
    /* Multiply next by m2 at very end: */
    beta_m2 += kappa3*betam23;
    gamma += kappa3*gamma3;
  }
    
/*     beta_g3 += kappa*betag31 + kappa2*betag32 + kappa3*betag33; */
/*     beta_g += kappa*betag1 + kappa2*betag2 + kappa3*betag3; */
/*     beta_gp += kappa*betagp1 + kappa2*betagp2 + kappa3*betagp3; */
/*     beta_yt += kappa*betayt1 + kappa2*betayt2 + kappa3*betayt3; */
/*     beta_yb += kappa*betayb1 + kappa2*betayb2 + kappa3*betayb3; */
/*     beta_ytau += kappa*betaytau1 + kappa2*betaytau2 + kappa3*betaytau3; */
/*     beta_k += kappa*betak1 + kappa2*betak2 + kappa3*betak3; */
/*     beta_m2 += m2*(kappa*betam21 + kappa2*betam22 + kappa3*betam23); */
/*     gamma += kappa*gamma1 + kappa2*gamma2 + kappa3*gamma3; */

  beta_m2 *= m2;

  beta_v = -v*gamma;

  return 0;
}  
