/* 
   Produces Higgs pole mass vs. MSbar renormalization scale data
   including tree, 1-loop, 1-loop plus 2-loop QCD, full 2-loop, and
   2-loop plus leading 3-loop QCD and non-QCD corrections.

   Compile as:

   gcc -DTSIL_SIZE_LONG -o fig_Mh_vs_Q fig_Mh_vs_Q.c -L. -lsmh -ltsil -lm

   (assuming libsmh.a and libtsil.a are in the current directory, and
   these were compiled using long double floating point data sizes),
   and run as

   ./fig_Mh_vs_Q

   The data is output in the file "FIG_Mh_vs_Q.dat" in 8 columns, respectively:
   Q, Mh(0), Mh(1), Mh(1.5), Mh(2), Mh(2.5), and Mh(3), where the number in
   parentheses is the loop order.
*/

#include <stdio.h>
#include <math.h>

#include "smhiggs.h"

#define QSTART 90
#define QEND   270
#define QSTEP  3


int main () {

  TSIL_REAL Q;
  FILE *outfile;
  char outFileName[] = "FIG_Mh_vs_Q.dat";

  /* Print version information: */
  SMH_Version ();

  /* Set benchmark parameters: */
  SMH_Q  = 173.10;
  SMH_gp = 0.35761;
  SMH_g  = 0.64822;
  SMH_g3 = 1.1666;
  SMH_yt = 0.93558;
  SMH_lambda = 0.12711;
  SMH_m2 = -(93.36*93.36);
  SMH_v = 247.03931235397684;

  /* Open output data file: */
  outfile = fopen (outFileName, "w");
  
  for (Q = QSTART; Q <= QEND; Q += QSTEP) {

    SMH_RGrun (Q, 3);

    fprintf (outfile, "%Lf", Q);
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (0));
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (1));
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (1.5));
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (2));
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (2.5));
    fprintf (outfile, "\t%Lf", SMH_Find_Mh (3));
    fprintf (outfile, "\n");
  }

  fclose (outfile);

  return 0;
}
