/* 
   Produces Higgs self coupling vs. MSbar renormalization scale data
   including the ratio of lambda calculated from a given Higgs pole
   mass and the value obtained by renormalization group running from
   the benchmark point.

   Compile as:

   gcc -DTSIL_SIZE_LONG -o fig_lambda_vs_Q fig_lambda_vs_Q.c -L. -lsmh
   -ltsil -lm

   (assuming libsmh.a and libtsil.a are in the current directory, and
   these were compiled using long double floating point data sizes),
   and run as

   ./fig_lambda_vs_Q

   The data is output in the file "FIG_lambda_vs_Q.dat" in 3 columns, respectively:
   Q, lambda(3), and lambda(3)/lambda(run), 
   where lambda(3) is the value obtained at Q from the input Higgs mass, 
   and lambda(run) is obtained by running the input value of lambda to the scale Q.
*/

#include <stdio.h>
#include <math.h>

#include "smhiggs.h"

#define QSTART 90
#define QEND   270
#define QSTEP  3


int main () {

  TSIL_REAL Q, res;
  FILE *outfile;
  char outFileName[] = "FIG_lambda_vs_Q.dat";

  /* Print version information: */
  SMH_Version ();

  /* Set benchmark parameters: */
  SMH_Q  = 173.10;
  SMH_gp = 0.35761;
  SMH_g  = 0.64822;
  SMH_g3 = 1.1666;
  SMH_yt = 0.93558;
  SMH_lambda = 0.12711;
  SMH_m2 = -(93.36*93.36);
  SMH_v = 247.03931235397684;

  /* Open output data file: */
  outfile = fopen (outFileName, "w");
  
  for (Q = QSTART; Q <= QEND; Q += QSTEP) {

    SMH_RGrun (Q, 3);

    fprintf (outfile, "%Lf", Q);

    res = SMH_Find_lambda (125.817674445041746, 3);
    fprintf (outfile, "\t%Lf\t%Lf", res, res/SMH_lambda);
    fprintf (outfile, "\n");
  }

  fclose (outfile);

  return 0;
}
