/*
   Produces Higgs lagrangian mass^2 parameter vs. MSbar
   renormalization scale data, determined by minimization of the
   scalar effective potential.

   Compile as:

   gcc -DTSIL_SIZE_LONG -o fig_m2_vs_Q fig_m2_vs_Q.c -L. -lsmh -ltsil -lm

   (assuming libsmh.a and libtsil.a are in the current directory, and
   these were compiled using long double floating point data sizes),
   and run as

   ./fig_m2_vs_Q

   The data is output in the file "FIG_m2_vs_Q.dat" in 5 columns, respectively:
   Q, sqrt(-m2(2)), sqrt(-m2(3)), m2(2)/m2(run), m2(3)/m2(run)
   where m2(n) is the value of m2 obtained by requiring the  effective potential
   to be minimized at Q at n-loop order, and m2(run) is obtained by directly running 
   the input value of m2 to the scale Q using 3-loop RG equations.
*/

#include <stdio.h>
#include <math.h>
#include "smhiggs.h"

#define QSTART 90
#define QEND   270
#define QSTEP  3

int main () {

  TSIL_REAL Q, result2, result3;
  FILE *outfile;
  char outFileName[] = "FIG_m2_vs_Q.dat";

  /* Print version information: */
  SMH_Version ();

  /* Set input parameters: */
  SMH_Q  = 173.1;
  SMH_lambda = 0.12711;
  SMH_yt = 0.93558;
  SMH_g3 = 1.1666;
  SMH_g  = 0.64822;
  SMH_gp = 0.35761;
  SMH_v = 247.03931235397684;
  SMH_m2 = -(93.36*93.36);

  /* Open output data file: */
  outfile = fopen (outFileName, "w");
  
  for (Q = QSTART; Q <= QEND; Q += QSTEP) {

    SMH_RGrun (Q, 3);

    fprintf (outfile, "%Lf", Q);

    result2 = SMH_Find_m2 (2);
    result3 = SMH_Find_m2 (3);

    fprintf (outfile, "\t%Lf\t%Lf", TSIL_SQRT(-result2), TSIL_SQRT(-result3));
    fprintf (outfile, "\t%Lf\t%Lf", result2/SMH_m2, result3/SMH_m2);

    fprintf (outfile, "\n");
  }

  fclose (outfile);

  return 0;
}
