/* General header file for internal use.  Users should include
   smhiggs.h instead! */

#ifndef _SMH_INTERNAL_H_
#define _SMH_INTERNAL_H_

/* First, a bunch of C standard library stuff: */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>

/* Then the local headers: */
#include "smhiggs.h"    /* This also includes tsil.h */
#include "smh_build.h"  /* Version information */
#include "smh_funcs.h"  /* Functions not in the user API */

/* These may eventually go in a separate .h file so they can be
   selectively excluded... */
#define Q    SMH_Q
#define g3   SMH_g3
#define gp   SMH_gp
#define g    SMH_g
#define yt   SMH_yt
#define m2   SMH_m2
#define v    SMH_v
#define k    SMH_lambda
#define yb   0
#define ytau 0

/* Tree-level running squared masses: */
TSIL_REAL T, W, Z, G, H, h, b, tau;

/* Some useful combinations: */
TSIL_REAL v2, v4, Q2;
TSIL_REAL g2, g3_, g4, g5, g6, g8, g10;
TSIL_REAL g32, g33, g34, g35, g36;
TSIL_REAL gp2, gp3, gp4, gp5, gp6, gp8;
TSIL_REAL yt2, yt3, yt4, yt5, yt6, yt7, yt8;
/* TSIL_REAL yb2, yb3, yb4, yb5, yb6, yb7, yb8; */
/* TSIL_REAL ytau2, ytau3, ytau4, ytau5, ytau6, ytau7, ytau8; */
TSIL_REAL k2, k3, k4;

/* Beta functions: */
TSIL_REAL beta_gp, beta_g, beta_g3, beta_yt, beta_yb;
TSIL_REAL beta_ytau, beta_k, beta_m2, beta_v;

/* Miscellaneous constants: */
/* 1/(16 pi^2) */
#define ONELOOPFACTOR (0.00633257397764611071524247L)
/* 1/(16 pi^2)^2 */
#define TWOLOOPFACTOR (0.0000401014931823606843326281L)
/* 1/(16 pi^2)^3 */
#define THREELOOPFACTOR (0.0000002539456721913701894751L)

#ifndef PI
#define PI     3.1415926535897932385L
#endif
#define PI2    9.8696044010893586188L
#define ln2    0.69314718055994530942L
#define Zeta3  1.2020569031595942854L
#define SQRT2  1.41421356237309504880169L

/* Possibly useful enums: */
enum {FALSE, TRUE};

/* Enums for indexing */
enum {Bxz, Byu};
enum { xz,  yu};

enum {Svyz, Suxv};

enum {Tvyz, Tuxv, Tyzv, Txuv, Tzyv, Tvxu};
enum { vyz,  uxv,  yzv,  xuv,  zyv,  vxu};

enum {Uzxyv, Uuyxv, Uxzuv, Uyuzv};
enum {Vzxyv, Vuyxv, Vxzuv, Vyuzv};
enum { zxyv,  uyxv,  xzuv,  yuzv};

#endif /* internal.h */
