#ifndef _SMHIGGS_H_
#define _SMHIGGS_H_

#include "tsil.h"

/* Standard Model Parameters: */
TSIL_REAL SMH_Q;      /* MSbar renormalization scale */
TSIL_REAL SMH_g3;     /* SU(3) gauge coupling */
TSIL_REAL SMH_gp;     /* U(1)_Y gauge coupling */
TSIL_REAL SMH_g;      /* SU(2) gauge coupling */
TSIL_REAL SMH_yt;     /* Top Yukawa coupling */
TSIL_REAL SMH_lambda; /* Higgs self coupling */
TSIL_REAL SMH_m2;     /* Higgs lagrangian mass^2 parameter */
TSIL_REAL SMH_v;      /* Higgs VEV */

/* ------ User API ------ */

/* RGrun.c: */
int SMH_RGrun (TSIL_REAL, int);

/* effpot.c: */
TSIL_REAL SMH_Veff (int);
TSIL_REAL SMH_Find_m2 (int);
TSIL_REAL SMH_Find_vev (int);

/* m2h.c: */
TSIL_REAL SMH_Find_Mh (float);
TSIL_REAL SMH_Find_lambda (TSIL_REAL, float);

/* utilities.c: */
void SMH_DisplayParameters (void);
void SMH_DisplayModel (void);
void SMH_Update (void);
void SMH_Version (void);
void SMH_Check_Mh_range (TSIL_REAL);
void SMH_Check_Q_range (void);
void SMH_Check_g3_range (void);
void SMH_Check_g_range (void);
void SMH_Check_gp_range (void);
void SMH_Check_lambda_range (void);
void SMH_Check_m2_range (void);
void SMH_Check_vev_range (void);
void SMH_Check_yt_range (void);

/* messages.c: */
void SMH_Error (char *, char *, int);
void SMH_Warn (char *, char *);

#endif /* smhiggs.h */
