#include "smh_internal.h"
#include <string.h>

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Updates useful parameter combos. */

void SMH_Update (void)
{
  v2 = v*v;
  v4 = v2*v2;
  Q2 = Q*Q;

  g2 = g*g;
  g3_ = g2*g;
  g4 = g2*g2;
  g5 = g4*g;
  g6 = g5*g;
  g8 = g6*g2;
  g10 = g5*g5;

  g32 = g3*g3;
  g33 = g32*g3;
  g34 = g33*g3;
  g35 = g34*g3;
  g36 = g35*g3;

  gp2 = gp*gp;
  gp3 = gp2*gp;
  gp4 = gp3*gp;
  gp5 = gp4*gp;
  gp6 = gp5*gp;
  gp8 = gp5*gp3;

  yt2 = yt*yt;
  yt3 = yt2*yt;
  yt4 = yt2*yt2;
  yt5 = yt4*yt;
  yt6 = yt4*yt2;
  yt7 = yt6*yt;
  yt8 = yt4*yt4;

  /* For possible later use... */
/*   yb2 = yb*yb; */
/*   yb3 = yb2*yb; */
/*   yb4 = yb2*yb2; */
/*   yb5 = yb4*yb; */
/*   yb6 = yb4*yb2; */
/*   yb7 = yb6*yb; */
/*   yb8 = yb4*yb4; */

/*   ytau2 = ytau*ytau; */
/*   ytau3 = ytau2*ytau; */
/*   ytau4 = ytau2*ytau2; */
/*   ytau5 = ytau4*ytau; */
/*   ytau6 = ytau4*ytau2; */
/*   ytau7 = ytau6*ytau; */
/*   ytau8 = ytau4*ytau4; */
 
  k2 = k*k;
  k3 = k2*k;
  k4 = k3*k;

  /* Finally update lagrangian mass squared parameters: */
  T = yt2 * v2/2;
  W = g2 * v2/4;
  Z = (g2 + gp2) * v2/4;
  G = m2 + k * v2;
  H = m2 + 3 * k * v2;
  h = 2.0 * k * v2;

  b = 0.0;
  tau = 0.0;

/*   b = yb2 * v2/2; */
/*   tau = ytau2 * v2/2; */

  return;
}


/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Prints program name and version number. */

void SMH_Version (void) 
{
  printf("(* %s Version %s *)\n", SMH_NAME, SMH_VERSION);
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Displays basic parameter values. */

void SMH_DisplayParameters (void)
{
/*   printf("\nCurrent model parameters:\n"); */
  printf("Q      = %13.10Lf\n", Q);
  printf("m2     = %13.10Lf\n", m2);
  printf("lambda = %13.10Lf\n", k);
  printf("yt     = %13.10Lf\n", yt);
/*   printf("yb   = %13.10Lf\n", yb); */
/*   printf("ytau = %13.10Lf\n", ytau); */
  printf("g3     = %13.10Lf\n", g3);
  printf("g      = %13.10Lf\n", g);
  printf("gp     = %13.10Lf\n", gp);
  printf("v      = %13.10Lf\n", v);
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Displays basic parameters and lagrangian mass^2 values. */

void SMH_DisplayModel ()
{
  printf("\nCurrent model parameters:\n");
  SMH_DisplayParameters ();

  printf("\nLagrangian mass^2 parameters:\n");
  printf("T   = %Lf\n", T);
  printf("W   = %Lf\n", W);
  printf("Z   = %Lf\n", Z);
  printf("G   = %Lf\n", G);
  printf("H   = %Lf\n", H);
  printf("h   = %Lf\n", h);
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_Q_range (void)
{
  char funcname[] = "Check_Q_range";

  if (Q < 25 || Q > 500)
    SMH_Warn (funcname, "An input value for Q seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_vev_range (void)
{
  char funcname[] = "Check_vev_range";

  if (v < 200 || v > 300)
    SMH_Warn (funcname, "The input value for v seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_m2_range (void)
{
  char funcname[] = "Check_m2_range";

  if ((m2 > -60*60) || (m2 < -120*120))
    SMH_Warn (funcname, "The input value for m2 seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_lambda_range (void)
{
  char funcname[] = "Check_lambda_range";

  if (k < 0.05 || k > 0.2)
    SMH_Warn (funcname, "The input value for lambda seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_yt_range (void)
{
  char funcname[] = "Check_yt_range";

  if (yt < 0.5 || yt > 1.5)
    SMH_Warn (funcname, "The input value for yt seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_g3_range (void)
{
  char funcname[] = "Check_g3_range";

  if (g3 < 0.5 || g3 > 2.0)
    SMH_Warn (funcname, "The input value for g3 seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_g_range (void)
{
  char funcname[] = "Check_g_range";

  if (g < 0.4 || g > 0.8)
    SMH_Warn (funcname, "The input value for g seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_gp_range (void)
{
  char funcname[] = "Check_gp_range";

  if (gp < 0.2 || gp > 0.5)
    SMH_Warn (funcname, "The input value for gp seems inappropriate.");

  return;
}

/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */

void SMH_Check_Mh_range (TSIL_REAL testMh)
{
  char funcname[] = "Check_Mh_range";

  if (testMh < 120 || testMh > 130)
    SMH_Warn (funcname, "The input value for Mh seems inappropriate.");

  return;
}
